@@ -12,14 +12,15 @@ class Node:
         """
         self.namespace = namespace
 
-    def send(self, channel, data=None):
+    def send(self, channel, data=None, auto_flush=False):
         """
         Send an object to a specific channel in the shared namespace.
 
         :param channel: The channel to send the object to.
         :param data: Additional data for the object.
+        :param auto_flush: Whether or not to automatically flush the object after receiving it.
         """
-        data = Object(data=data, channel=channel, namespace=self.namespace)
+        data = Object(data=data, channel=channel, namespace=self.namespace, auto_flush=auto_flush)
 
         setattr(self.namespace, channel, data)
 
@@ -35,13 +36,16 @@ class Node:
             if not value:
                 value = Object(None, channel, self.namespace)
 
+            if value.auto_flush:
+                self.namespace[channel] = None
+
             return value.data
         except AttributeError:
             return None
 
 
 class Object:
-    def __init__(self, data, channel, namespace):
+    def __init__(self, data, channel, namespace, auto_flush=False):
         """
         Initialize an Object with a header, data, and channel.
 
@@ -52,6 +56,7 @@ class Object:
         self.data = data
         self.channel = channel
         self.namespace = namespace
+        self.auto_flush = auto_flush
 
     def flush(self):
         """
