@@ -100,6 +100,12 @@ class Utilities:
     def get_current_window_title():
         return win32gui.GetWindowText(win32gui.GetForegroundWindow())
 
+    @staticmethod
+    def get_current_window_pid():
+        hwnd = win32gui.GetForegroundWindow()
+        _, pid = win32process.GetWindowThreadProcessId(hwnd)
+        return pid
+
     def get_window_title_from_pid(self, pid):
         handle = self.get_handle_from_pid(pid)
         return self.get_window_title_from_handle(handle)
@@ -107,6 +113,12 @@ class Utilities:
     def is_current_window_title(self, window_name: str):
         return window_name == self.get_current_window_title()
 
+    def is_current_window_pid(self, pid: int):
+        return pid == self.get_current_window_pid()
+
+    # Get current window pid
+
+
     @staticmethod
     def get_window_title_from_handle(hwnd):
         length = GetWindowTextLength(hwnd)
